# cdfwriter package

This is a Python package developed at Southwest Research Institute
that aims to provide a simple and efficient solution to generating CDF files.

It uses a high level Object-Oriented interface method that allows for
the definition of a common set of CDF files that are similar.

The cdfwriter package uses spacepy.pycdf to write a common set of CDFs
and makes use of the numpy package.
